==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/InstanceType.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Instance type for EC2 instances.
 * 
 * This class takes a literal string, good if you already
 * know the identifier of the type you want.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.071Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InstanceType")
public class InstanceType extends software.amazon.jsii.JsiiObject {

    protected InstanceType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InstanceType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param instanceTypeIdentifier This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public InstanceType(final java.lang.String instanceTypeIdentifier) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(instanceTypeIdentifier, "instanceTypeIdentifier is required") }));
    }

    /**
     * Instance type for EC2 instances.
     * 
     * This class takes a combination of a class and size.
     * 
     * Be aware that not all combinations of class and size are available, and not all
     * classes are available in all regions.
     * 
     * @param instanceClass This parameter is required.
     * @param instanceSize This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.InstanceType of(final software.amazon.awscdk.services.ec2.InstanceClass instanceClass, final software.amazon.awscdk.services.ec2.InstanceSize instanceSize) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InstanceType.class, "of", software.amazon.awscdk.services.ec2.InstanceType.class, new Object[] { java.util.Objects.requireNonNull(instanceClass, "instanceClass is required"), java.util.Objects.requireNonNull(instanceSize, "instanceSize is required") });
    }

    /**
     * Return the instance type as a dotted string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/InstanceType.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Instance type for EC2 instances.
 * 
 * This class takes a literal string, good if you already
 * know the identifier of the type you want.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.805Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InstanceType")
public class InstanceType extends software.amazon.jsii.JsiiObject {

    protected InstanceType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InstanceType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param instanceTypeIdentifier This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public InstanceType(final java.lang.String instanceTypeIdentifier) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(instanceTypeIdentifier, "instanceTypeIdentifier is required") });
    }

    /**
     * Instance type for EC2 instances.
     * 
     * This class takes a combination of a class and size.
     * 
     * Be aware that not all combinations of class and size are available, and not all
     * classes are available in all regions.
     * 
     * @param instanceClass This parameter is required.
     * @param instanceSize This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.InstanceType of(final software.amazon.awscdk.services.ec2.InstanceClass instanceClass, final software.amazon.awscdk.services.ec2.InstanceSize instanceSize) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InstanceType.class, "of", software.amazon.awscdk.services.ec2.InstanceType.class, new Object[] { java.util.Objects.requireNonNull(instanceClass, "instanceClass is required"), java.util.Objects.requireNonNull(instanceSize, "instanceSize is required") });
    }

    /**
     * Return the instance type as a dotted string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }
}
